import { NextApiRequest, NextApiResponse } from "next";
import { z } from "zod";
import { OrPromise, RawType, ValueOf } from "./utils";
export interface ZodRouteSchema<TQuery extends z.ZodType = z.ZodType, TBody extends z.ZodType = z.ZodType, TResponses extends Record<number, z.ZodType> = Record<number, z.ZodType>> {
    method: string;
    query?: TQuery;
    body?: TBody;
    responses: TResponses;
}
type ZodInferOrUndefined<T extends z.ZodType | undefined> = T extends undefined ? undefined : z.infer<NonNullable<T>>;
export type ZodRouteSchemaToSchema<TSchema extends ZodRouteSchema> = {
    query: ZodInferOrUndefined<TSchema["query"]>;
    body: ZodInferOrUndefined<TSchema["body"]>;
    responses: {
        [code in keyof TSchema["responses"] & number]: ZodInferOrUndefined<TSchema["responses"][code]>;
    };
};
export declare const zodRouteSchema: <TProps extends ZodRouteSchema<z.ZodType<any, z.ZodTypeDef, any>, z.ZodType<any, z.ZodTypeDef, any>, Record<number, z.ZodType<any, z.ZodTypeDef, any>>>>(props: TProps) => TProps;
export declare function zodRoute<TSchema extends ZodRouteSchema>(schema: TSchema, handler: (req: Omit<NextApiRequest, "body"> & {
    query: RawType<TSchema["query"]>;
    body: RawType<TSchema["body"]>;
}, res: NextApiResponse<RawType<ValueOf<TSchema["responses"]>>>) => OrPromise<Partial<{
    [code in keyof TSchema["responses"]]: RawType<ValueOf<TSchema["responses"][code]>>;
}> | void>): typeof handler;
export {};
